@@ -30,15 +30,29 @@ public class LocalRequestDispatcher implements RequestDispatcher {
     // Name of the exposed MBeanServerHandler-MBean
     private ObjectName mbeanServerHandlerMBeanName;
 
+    // An (optional) qualifier for registering MBeans.
+    private String qualifier;
+
+    /**
+     * Create a new local dispatcher which accesses local MBeans.
+     *
+     * @param objectToJsonConverter a serializer to JSON
+     * @param stringToObjectConverter a de-serializer for arguments
+     * @param restrictor restrictor which checks the access for various operations
+     * @param pQualifier optional qualifier for registering own MBean to allow for multiple J4P instances in the VM
+     */
     public LocalRequestDispatcher(ObjectToJsonConverter objectToJsonConverter,
                                   StringToObjectConverter stringToObjectConverter,
-                                  Restrictor restrictor) {
+                                  Restrictor restrictor, String pQualifier) {
         requestHandlerManager = new RequestHandlerManager(objectToJsonConverter,stringToObjectConverter,restrictor);
         // Get all MBean servers we can find. This is done by a dedicated
         // handler object
-        mBeanServerHandler = new MBeanServerHandler();
+        mBeanServerHandler = new MBeanServerHandler(pQualifier);
+        qualifier = pQualifier;
     }
 
+
+
     // Can handle any request
     public boolean canHandle(JmxRequest pJmxRequest) {
         return true;
@@ -55,9 +69,12 @@ public class LocalRequestDispatcher implements RequestDispatcher {
         return mBeanServerHandler.dispatchRequest(handler, pJmxReq);
     }
 
-    public void init(HistoryStore pHistoryStore, DebugStore pDebugStore) throws MalformedObjectNameException, MBeanRegistrationException, InstanceAlreadyExistsException, NotCompliantMBeanException {
-        configMBeanName = registerMBean(new Config(pHistoryStore,pDebugStore),Config.OBJECT_NAME);
-        mbeanServerHandlerMBeanName = registerMBean(mBeanServerHandler,MBeanServerHandlerMBean.OBJECT_NAME);
+    public void init(HistoryStore pHistoryStore, DebugStore pDebugStore)
+            throws MalformedObjectNameException, MBeanRegistrationException, InstanceAlreadyExistsException, NotCompliantMBeanException {
+        Config config = new Config(pHistoryStore,pDebugStore,qualifier);
+        configMBeanName = registerMBean(config,config.getObjectName());
+
+        mbeanServerHandlerMBeanName = registerMBean(mBeanServerHandler,mBeanServerHandler.getObjectName());
     }
 
     public void destroy() throws MalformedObjectNameException, InstanceNotFoundException, MBeanRegistrationException {
